diff mbox series

[v9,68/96] mm/filemap: Add i_blocks_per_folio

Message ID 20210505150628.111735-69-willy@infradead.org (mailing list archive)
State New, archived
Headers show
Series Memory folios | expand

Commit Message

Matthew Wilcox May 5, 2021, 3:06 p.m. UTC
Reimplement i_blocks_per_page() as a wrapper around i_blocks_per_folio().

Signed-off-by: Matthew Wilcox (Oracle) <willy@infradead.org>
---
 include/linux/pagemap.h | 18 ++++++++++++------
 1 file changed, 12 insertions(+), 6 deletions(-)
diff mbox series

Patch

diff --git a/include/linux/pagemap.h b/include/linux/pagemap.h
index fa24217e305d..2f896574aad7 100644
--- a/include/linux/pagemap.h
+++ b/include/linux/pagemap.h
@@ -1224,19 +1224,25 @@  static inline int page_mkwrite_check_truncate(struct page *page,
 }
 
 /**
  * i_blocks_per_page - How many blocks fit in this page.
  * @inode: The inode which contains the blocks.
- * @page: The page (head page if the page is a THP).
+ * @folio: The folio.
  *
  * If the block size is larger than the size of this page, return zero.
  *
  * Context: The caller should hold a refcount on the page to prevent it
  * from being split.
  * Return: The number of filesystem blocks covered by this page.
  */
+static inline
+unsigned int i_blocks_per_folio(struct inode *inode, struct folio *folio)
+{
+	return folio_size(folio) >> inode->i_blkbits;
+}
+
 static inline
 unsigned int i_blocks_per_page(struct inode *inode, struct page *page)
 {
-	return thp_size(page) >> inode->i_blkbits;
+	return i_blocks_per_folio(inode, page_folio(page));
 }
 #endif /* _LINUX_PAGEMAP_H */
@@ -1224,19 +1224,25 @@  static inline int page_mkwrite_check_truncate(struct page *page,
 
 /**
- * i_blocks_per_page - How many blocks fit in this page.
+ * i_blocks_per_folio - How many blocks fit in this folio.
  * @inode: The inode which contains the blocks.
@@ -1224,19 +1224,25 @@  static inline int page_mkwrite_check_truncate(struct page *page,
  *
- * If the block size is larger than the size of this page, return zero.
+ * If the block size is larger than the size of this folio, return zero.
  *
@@ -1224,19 +1224,25 @@  static inline int page_mkwrite_check_truncate(struct page *page,
  *
- * Context: The caller should hold a refcount on the page to prevent it
+ * Context: The caller should hold a refcount on the folio to prevent it
  * from being split.
@@ -1224,19 +1224,25 @@  static inline int page_mkwrite_check_truncate(struct page *page,
  * from being split.
- * Return: The number of filesystem blocks covered by this page.
+ * Return: The number of filesystem blocks covered by this folio.
  */